﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Drawing;
using GeoTools.General;

namespace GeoTools.Shapes
{
    internal class Rectangle : GeoBase, IGeoObject
    {
        double[] position;
        double width;
        double height;

        public Rectangle(List<KeyValuePair<string, double>> args)
        {
            position = new double[2];
            foreach (var pair in args)
            {
                if (pair.Key == "x")
                    position[0] = pair.Value;
                else if (pair.Key == "y")
                    position[1] = pair.Value;
                else if (pair.Key == "w")
                    width = (pair.Value);
                else if (pair.Key == "h")
                    height = (pair.Value);
            }
        }
        public Rectangle(double[] position, double width, double height)
        {
            position = new double[2];
            position[0] = position[0];
            position[1] = position[1];

            this.width = width;
            this.height = height;
        }

        public double[] Position { get { return position; } }
        public double Width { get { return width; } }
        public double Height { get { return height; } }

        public double Perimeter { get { return 2 * (width + height); } }
        public double Area { get { return width * height; } }
        public double[][] Points
        {
            get
            {
                return new double[][]{
                            new double[] {position[0], position[1] },
                            new double[] { position[0] + width, position[1] },
                            new double[] { position[0] + width, position[1] + height },
                            new double[] { position[0], position[1] + height }
                    };
            }
        }
        public override void Draw(Graphics g)
        {
            g.DrawRectangle(Pens.Blue, (float)Position[0], (float)Position[1], (float)width, (float)height);
        }

        public override string ToString()
        {
            return "Rectangle: " + Environment.NewLine
                + "    position : (" + Position[0] + "," + Position[1] + ")" + Environment.NewLine
                + "    width    : " + width + Environment.NewLine
                + "    height   : " + height + Environment.NewLine;
        }
    }
}
